BaseMessage

Struct BaseMessage 

pub struct BaseMessage {
    pub msg_type: MessageType,
    pub id: u16,
    pub refers_to: u16,
    pub sent: Timeval,
    pub received: Timeval,
    pub size: u32,
}
Base message header (26 bytes).

Every Snapcast protocol message starts with this header, followed by size bytes of typed payload.

Fields

msg_type: MessageType

Type of the message payload.

id: u16

Sequence identifier.

refers_to: u16

ID of the message this is a response to.

sent: Timeval

Timestamp when the message was sent.

received: Timeval

Timestamp when the message was received.

size: u32

Size of the payload in bytes.

Implementations

Source

impl BaseMessage

pub const HEADER_SIZE: usize = 26

Size of the serialized header in bytes.

pub fn read_from<R: Read>(r: &mut R) -> Result<Self, ProtoError>

Deserialize a base message header from a reader.

pub fn write_to<W: Write>(&self, w: &mut W) -> Result<(), ProtoError>

Serialize a base message header to a writer.

pub fn to_bytes(&self) -> Result<Vec<u8>, ProtoError>

Serialize to a new Vec<u8>.