pub struct BaseMessage {
pub msg_type: MessageType,
pub id: u16,
pub refers_to: u16,
pub sent: Timeval,
pub received: Timeval,
pub size: u32,
}Expand description
Base message header (26 bytes).
Every Snapcast protocol message starts with this header, followed by
size bytes of typed payload.
Fields
msg_type: MessageTypeType of the message payload.
id: u16Sequence identifier.
refers_to: u16ID of the message this is a response to.
sent: TimevalTimestamp when the message was sent.
received: TimevalTimestamp when the message was received.
size: u32Size of the payload in bytes.
Implementations
Sourceimpl BaseMessage
impl BaseMessage
Sourcepub const HEADER_SIZE: usize = 26
pub const HEADER_SIZE: usize = 26
Size of the serialized header in bytes.
Sourcepub fn read_from<R: Read>(r: &mut R) -> Result<Self, ProtoError>
pub fn read_from<R: Read>(r: &mut R) -> Result<Self, ProtoError>
Deserialize a base message header from a reader.